@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+
 import platform
 import sys
 
@@ -170,20 +172,16 @@ def _guess_architecture():
     """
     Returns the architecture of the running python.
     """
-    x86 = "x86"
-    amd64 = "amd64"
-    bits = platform.architecture()[0]
     machine = platform.machine()
-    if machine in ("AMD64", "x86_64"):
-        if bits == "32bit":
-            return x86
-        elif bits == "64bit":
-            return amd64
-    elif machine in ("x86", "i386", "i686") and bits == "32bit":
-        return x86
+
+    if machine in ("AMD64", "x86_64", "x86", "i386", "i686"):
+        if sys.maxsize > 2 ** 32:
+            return "amd64"
+        else:
+            return "x86"
     else:
-        raise OkonomiyakiError("Unknown bits/machine combination {0}/{1}".
-                               format(bits, machine))
+        raise OkonomiyakiError("Unknown machine combination {0!r}".
+                               format(machine))
 
 
 def _guess_epd_platform(arch=None):
