@@ -1,8 +1,7 @@
 from ..bundled.traitlets import HasTraits, Enum, Instance
 from ..errors import OkonomiyakiError
 from ..file_formats.egg import egg_name, split_egg_name
-from ..platforms import EPD_PLATFORM_SHORT_NAMES
-from ..platforms.epd_platform import EPDPlatform
+from ..platforms.epd_platform import EPD_PLATFORM_SHORT_NAMES, EPDPlatform
 
 from .enpkg import EnpkgS3IndexEntry
 
