@@ -1,7 +1,14 @@
+from __future__ import absolute_import
+
+__all__ = ["ZipFile", "compute_md5", "parse_assignments"]
+
 import hashlib
 
 import six
 
+from .misc import parse_assignments
+from ._compat import ZipFile
+
 
 def compute_md5(path):
     """Compute the md5 checksum of the given path.
